@@ -6,14 +6,14 @@
 # version of R devel, which automatically add namespaces to packages
 # who do not have one, we explicitly have specify the following.
 # /HB 2011-07-27
-cat <- R.utils::cat;
-getOption <- R.utils::getOption;
+##cat <- R.utils::cat;
+##getOption <- R.utils::getOption;
+##lapply <- R.utils::lapply;
 append <- R.filesets::append;
-lapply <- R.utils::lapply;
 sapply <- R.filesets::sapply;
 
-.First.lib <- function(libname, pkgname) {
-## .onAttach <- function(libname, pkgname) {
+##.First.lib <- function(libname, pkgname) {
+.onAttach <- function(libname, pkgname) {
   pkg <- AromaCore(pkgname);
   assign(pkgname, pkg, pos=getPosition(pkg));
 
